#
# spec file for package kustomize
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kustomize
Version:        3.10.0
Release:        bp156.3.9
Summary:        Customization of kubernetes YAML configurations
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/kubernetes-sigs/kustomize
Source:         https://github.com/kubernetes-sigs/kustomize/archive/kustomize/v%{version}.tar.gz#/%{name}-%{name}-v%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  golang(API) = 1.13
ExcludeArch:    s390
ExcludeArch:    %{ix86}
%ifarch %arm aarch64
BuildRequires:  binutils-gold
%endif

%description
kustomize customizes raw, template-free kubernetes YAML files for
multiple purposes, leaving the original YAML untouched and usable
as is.

%prep
%setup -qa1 -n %{name}-%{name}-v%{version}

%build
cd kustomize
go build -mod vendor -buildmode=pie .

%install
# Install the binary.
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 kustomize/kustomize %{buildroot}%{_bindir}

%files
%license LICENSE
%{_bindir}/kustomize

%changelog
* Wed Feb 10 2021 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.10.0
  - Pin to api v0.8.0
  - Delete dependence on k8s.io/...
  - Unpin from api.
- Refresh vendor.tar.xz
* Mon Jan 18 2021 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.9.2
  - Pin to api v0.7.2
  - Pin to cmd/config v0.8.8
  - Pin to kyaml v0.10.6 and cli-utils v0.22.4
  - Move plugin lister to avoid import cycle.
  - Unpin kyaml, cmd/config, api
- Refresh vendor.tar.xz
* Wed Dec 30 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to verison 3.9.1
  - Pin to api/v0.7.1 (--enableKyaml=true)
  - Pin to api/v0.6.8
  - Pin to cmd/confg v0.8.7
  - Pin to kyaml v0.10.5
  - Pin to gopkg.in/yaml.v3 v3.0.0-20200313102051-9f266ea9e77c
  - In module replacements, drop specific version numbers.
  - Unpin kyaml
  - Unpin api module.
  - describe the format of image tag that is allowed
  - Unpin api
- Refresh vendor.tar.xz
* Fri Dec 11 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.9.0
  - Auto update go.sum
  - Pin kustomize to api/v0.7.0, enabling kyaml by default
  - Flip default value of --enable_kyaml from false to true.
- Update to version 3.8.8
  - Pin kustomize to api/v0.6.7
  - Pin to api v0.6.7
  - Unpin kustomize from api.
  - Pin to api v0.6.6
  - Pin to cmd/config v0.8.6
  - Pin to kyaml v0.10.3 cliutils v0.22.1
  - Automated Go mod cache updates.
  - Revert "helm values on inflator config"
  - helm values on inflator config spec.
  - connected allowresourcesidchanges bool to allow_id_changes flag
  - Automated go.sum updates.
  - update Go version to 1.15
  - Use DepProvider in tests to access kyaml impls.
  - mark the list-builtin command alpha
  - Add command to list builtin plugins
  - added kustomize edit set label
  - Unpin everything post v3.8.7 release
- Refresh vendor.tar.xz
* Thu Nov 12 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.8.7
  - Pin to api_v0.6.5
- Refresh vendor.tar.xz
* Tue Nov 10 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.8.6
  - Pin to api 0.6.4
- Refresh vendor.tar.xz
* Thu Oct  8 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version 3.8.5
  - Pin to cmd/config/v0.8.2
- Refresh vendor.tar.xz
* Mon Sep 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 3.8.4
  - Update api to v0.6.2
  - Update kyaml to v0.8.1
- Refresh vendor.tar.xz
* Mon Jul  6 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 3.8.0
  - use kyaml
  - switch to api 0.5.0
- Refresh vendor.tar.xz
* Fri May 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 3.6.1
  - pin kustomize to cmd/kubectl_v0_1_0
- Refresh vendor.tar.xz
* Mon Jan 13 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 3.5.4
  - Upgrade some deps in kustomize.
  - Update VERSIONS for cmd/resource and cmd/config
* Sat Dec 28 2019 Thorsten Kukuk <kukuk@suse.com>
- Use binutils-gold on ARM
* Mon Dec 23 2019 kukuk@suse.de
- Initial version
